@@ -1,7 +1,7 @@
-from .api import Tistory
+from .api import Tistory, Auto
 from .config.info import __version__, __author__, __contact__, __github__
 
 __all__ = [
     "__version__", "__author__", "__contact__", "__github__", 
-    "Tistory"
+    "Tistory", "Auto",
 ]
\ No newline at end of file
